@@ -963,7 +963,7 @@ int r_jwt_generate_enc_iv(jwt_t * jwt) {
   int ret;
 
   if (jwt != NULL && jwt->enc != R_JWA_ENC_UNKNOWN) {
-    jwt->iv_len = gnutls_cipher_get_iv_size(_r_get_alg_from_enc(jwt->enc));
+    jwt->iv_len = (unsigned)gnutls_cipher_get_iv_size(_r_get_alg_from_enc(jwt->enc));
     o_free(jwt->iv);
     jwt->iv = NULL;
     if (jwt->iv_len) {
@@ -1692,7 +1692,7 @@ int r_jwt_verify_signature_nested(jwt_t * jwt, jwk_t * verify_key, int verify_ke
 
 int r_jwt_validate_claims(jwt_t * jwt, ...) {
   rhn_claim_opt option;
-  unsigned int ret = RHN_OK;
+  int ret = RHN_OK;
   int i_value;
   const char * str_key, * str_value;
   json_t * j_value, * j_expected_value;
@@ -1756,7 +1756,7 @@ int r_jwt_validate_claims(jwt_t * jwt, ...) {
           i_value = va_arg(vl, int);
           if (i_value == R_JWT_CLAIM_PRESENT && !json_is_integer(json_object_get(jwt->j_claims, "exp"))) {
             ret = RHN_ERROR_PARAM;
-          } else if (json_is_integer(json_object_get(jwt->j_claims, "exp"))) {
+          } else if (json_is_integer(json_object_get(jwt->j_claims, "exp")) && json_integer_value(json_object_get(jwt->j_claims, "exp")) > 0) {
             t_value = (time_t)r_jwt_get_claim_int_value(jwt, "exp");
             if (i_value == R_JWT_CLAIM_NOW) {
               if (t_value < now) {
@@ -1775,7 +1775,7 @@ int r_jwt_validate_claims(jwt_t * jwt, ...) {
           i_value = va_arg(vl, int);
           if (i_value == R_JWT_CLAIM_PRESENT && !json_is_integer(json_object_get(jwt->j_claims, "nbf"))) {
             ret = RHN_ERROR_PARAM;
-          } else if (json_is_integer(json_object_get(jwt->j_claims, "nbf"))) {
+          } else if (json_is_integer(json_object_get(jwt->j_claims, "nbf")) && json_integer_value(json_object_get(jwt->j_claims, "nbf")) > 0) {
             t_value = (time_t)r_jwt_get_claim_int_value(jwt, "nbf");
             if (i_value == R_JWT_CLAIM_NOW) {
               if (t_value > now) {
@@ -1794,7 +1794,7 @@ int r_jwt_validate_claims(jwt_t * jwt, ...) {
           i_value = va_arg(vl, int);
           if (i_value == R_JWT_CLAIM_PRESENT && !json_is_integer(json_object_get(jwt->j_claims, "iat"))) {
             ret = RHN_ERROR_PARAM;
-          } else if (json_is_integer(json_object_get(jwt->j_claims, "iat"))) {
+          } else if (json_is_integer(json_object_get(jwt->j_claims, "iat")) && json_integer_value(json_object_get(jwt->j_claims, "iat")) > 0) {
             t_value = (time_t)r_jwt_get_claim_int_value(jwt, "iat");
             if (i_value == R_JWT_CLAIM_NOW) {
               if (t_value > now) {
@@ -1874,7 +1874,7 @@ int r_jwt_validate_claims(jwt_t * jwt, ...) {
 
 int r_jwt_set_claims(jwt_t * jwt, ...) {
   rhn_claim_opt option;
-  unsigned int ret = RHN_OK;
+  int ret = RHN_OK;
   int i_value;
   const char * str_key, * str_value;
   json_t * j_value;
@@ -2173,7 +2173,7 @@ int r_jwt_set_properties(jwt_t * jwt, ...) {
           ui_value = va_arg(vl, unsigned int);
           ustr_value = va_arg(vl, const unsigned char *);
           size_value = va_arg(vl, size_t);
-          ret = r_jwt_add_enc_keys_pem_der(jwt, ui_value, NULL, 0, ustr_value, size_value);
+          ret = r_jwt_add_enc_keys_pem_der(jwt, (int)ui_value, NULL, 0, ustr_value, size_value);
           break;
         case RHN_OPT_DECRYPT_KEY_JWK:
           jwk = va_arg(vl, jwk_t *);
@@ -2199,7 +2199,7 @@ int r_jwt_set_properties(jwt_t * jwt, ...) {
           ui_value = va_arg(vl, unsigned int);
           ustr_value = va_arg(vl, const unsigned char *);
           size_value = va_arg(vl, size_t);
-          ret = r_jwt_add_enc_keys_pem_der(jwt, ui_value, ustr_value, size_value, NULL, 0);
+          ret = r_jwt_add_enc_keys_pem_der(jwt, (int)ui_value, ustr_value, size_value, NULL, 0);
           break;
         case RHN_OPT_VERIFY_KEY_JWK:
           jwk = va_arg(vl, jwk_t *);
@@ -2225,7 +2225,7 @@ int r_jwt_set_properties(jwt_t * jwt, ...) {
           ui_value = va_arg(vl, unsigned int);
           ustr_value = va_arg(vl, const unsigned char *);
           size_value = va_arg(vl, size_t);
-          ret = r_jwt_add_sign_keys_pem_der(jwt, ui_value, NULL, 0, ustr_value, size_value);
+          ret = r_jwt_add_sign_keys_pem_der(jwt, (int)ui_value, NULL, 0, ustr_value, size_value);
           break;
         case RHN_OPT_SIGN_KEY_JWK:
           jwk = va_arg(vl, jwk_t *);
@@ -2251,7 +2251,7 @@ int r_jwt_set_properties(jwt_t * jwt, ...) {
           ui_value = va_arg(vl, unsigned int);
           ustr_value = va_arg(vl, const unsigned char *);
           size_value = va_arg(vl, size_t);
-          ret = r_jwt_add_sign_keys_pem_der(jwt, ui_value, ustr_value, size_value, NULL, 0);
+          ret = r_jwt_add_sign_keys_pem_der(jwt, (int)ui_value, ustr_value, size_value, NULL, 0);
           break;
         default:
           ret = RHN_ERROR_PARAM;
