@@ -4,7 +4,7 @@
  *
  * misc.c: Misc functions definitions
  *
- * Copyright 2020-2021 Nicolas Mora <mail@babelouest.org>
+ * Copyright 2020-2022 Nicolas Mora <mail@babelouest.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -90,7 +90,7 @@ static size_t write_response(char *ptr, size_t size, size_t nmemb, void * userda
 static size_t write_header(void * buffer, size_t size, size_t nitems, void * user_data) {
   const char * header = (const char *)buffer;
   struct _r_expected_content_type * expected_content_type = (struct _r_expected_content_type *)user_data;
-  
+
   if (o_strncasecmp(header, _R_HEADER_CONTENT_TYPE, o_strlen(_R_HEADER_CONTENT_TYPE)) == 0 &&
      o_strstr(header+o_strlen(_R_HEADER_CONTENT_TYPE)+1, expected_content_type->expected)) {
     expected_content_type->found = 1;
@@ -106,7 +106,7 @@ char * _r_get_http_content(const char * url, int x5u_flags, const char * expecte
   struct curl_slist *list = NULL;
   struct _r_response_str resp;
   struct _r_expected_content_type ct;
-  int status = 0;
+  long status = 0;
 
   curl = curl_easy_init();
   if(curl != NULL) {
@@ -114,7 +114,7 @@ char * _r_get_http_content(const char * url, int x5u_flags, const char * expecte
     resp.len = 0;
     ct.expected = expected_content_type;
     ct.found = 0;
-    
+
     do {
       if (curl_easy_setopt(curl, CURLOPT_URL, url) != CURLE_OK) {
         break;
@@ -147,7 +147,7 @@ char * _r_get_http_content(const char * url, int x5u_flags, const char * expecte
           break;
         }
       }
-      if (o_strlen(expected_content_type)) {
+      if (!o_strnullempty(expected_content_type)) {
         if (curl_easy_setopt(curl, CURLOPT_HEADERFUNCTION, write_header) != CURLE_OK) {
           break;
         }
@@ -166,9 +166,9 @@ char * _r_get_http_content(const char * url, int x5u_flags, const char * expecte
 
     curl_easy_cleanup(curl);
     curl_slist_free_all(list);
-    
+
     if (status >= 200 && status < 300) {
-      if (!o_strlen(expected_content_type)) {
+      if (o_strnullempty(expected_content_type)) {
         to_return = resp.ptr;
       } else {
         if (ct.found) {
@@ -192,7 +192,7 @@ char * _r_get_http_content(const char * url, int x5u_flags, const char * expecte
 int _r_json_set_str_value(json_t * j_json, const char * key, const char * str_value) {
   int ret;
 
-  if (j_json != NULL && o_strlen(key)) {
+  if (j_json != NULL && !o_strnullempty(key)) {
     if (str_value != NULL) {
       if (!json_object_set_new(j_json, key, json_string(str_value))) {
         ret = RHN_OK;
@@ -213,7 +213,7 @@ int _r_json_set_str_value(json_t * j_json, const char * key, const char * str_va
 int _r_json_set_int_value(json_t * j_json, const char * key, rhn_int_t i_value) {
   int ret;
 
-  if (j_json != NULL && o_strlen(key)) {
+  if (j_json != NULL && !o_strnullempty(key)) {
     if (!json_object_set_new(j_json, key, json_integer(i_value))) {
       ret = RHN_OK;
     } else {
@@ -229,7 +229,7 @@ int _r_json_set_int_value(json_t * j_json, const char * key, rhn_int_t i_value)
 int _r_json_set_json_t_value(json_t * j_json, const char * key, json_t * j_value) {
   int ret;
 
-  if (j_json != NULL && o_strlen(key)) {
+  if (j_json != NULL && !o_strnullempty(key)) {
     if (j_value != NULL) {
       if (!json_object_set_new(j_json, key, json_deep_copy(j_value))) {
         ret = RHN_OK;
@@ -248,14 +248,14 @@ int _r_json_set_json_t_value(json_t * j_json, const char * key, json_t * j_value
 }
 
 const char * _r_json_get_str_value(json_t * j_json, const char * key) {
-  if (j_json != NULL && o_strlen(key)) {
+  if (j_json != NULL && !o_strnullempty(key)) {
     return json_string_value(json_object_get(j_json, key));
   }
   return NULL;
 }
 
 rhn_int_t _r_json_get_int_value(json_t * j_json, const char * key) {
-  if (j_json != NULL && o_strlen(key)) {
+  if (j_json != NULL && !o_strnullempty(key)) {
     return json_integer_value(json_object_get(j_json, key));
   }
   return 0;
@@ -264,7 +264,7 @@ rhn_int_t _r_json_get_int_value(json_t * j_json, const char * key) {
 json_t * _r_json_get_json_t_value(json_t * j_json, const char * key) {
   json_t * j_value;
 
-  if (j_json != NULL && o_strlen(key) && (j_value = json_object_get(j_json, key)) != NULL) {
+  if (j_json != NULL && !o_strnullempty(key) && (j_value = json_object_get(j_json, key)) != NULL) {
     return json_deep_copy(j_value);
   }
   return NULL;
@@ -339,10 +339,10 @@ gnutls_cipher_algorithm_t _r_get_alg_from_enc(jwa_enc enc) {
 int _r_deflate_payload(const unsigned char * uncompressed, size_t uncompressed_len, unsigned char ** compressed, size_t * compressed_len) {
   int ret = RHN_OK, res;
   z_stream defstream;
-  
+
   *compressed_len = 0;
   *compressed = NULL;
-  
+
   defstream.zalloc = Z_NULL;
   defstream.zfree = Z_NULL;
   defstream.opaque = Z_NULL;
@@ -382,7 +382,7 @@ int _r_deflate_payload(const unsigned char * uncompressed, size_t uncompressed_l
 int _r_inflate_payload(const unsigned char * compressed, size_t compressed_len, unsigned char ** uncompressed, size_t * uncompressed_len) {
   int ret = RHN_OK, res;
   z_stream infstream;
-  
+
   *uncompressed = NULL;
   *uncompressed_len = 0;
   infstream.zalloc = Z_NULL;
