@@ -16,6 +16,7 @@
 #define PS256_TOKEN_INVALID_PAYLOAD_B64 "eyJhbGciOiJQUzI1NiIsImtpZCI6IjEifQ.;error;.t2G7YMKJVZe0U1_ZM7efsGWhSAGia5JN-K4lAk3IX7NsMSrWHwZufBXMYZW6S7t_N8xkWEuAgHOY1etwxXuUdhw8uotA-E66M-fErP8MH-N5yUR2G60g3DkcVD-GwbBCsA-Jzum_psaXMA08-3zBjrvGbldqyM51rcdt2qSDxjZ7yxRVhbFbKD0qPOUH49WZx6Mld9oMMSUoIarJitY9LwIC0cR2lXULIh5E-xia42TsNIw9F7VwPXGdHc7_VBqT7R4soxQjWDmfk5QXSMDw2WTIfEXdI3VJiUQ5qnIAe5WWW-wPsK8ughxHLabKXEQ4j7op8EvhZziLOgntGmqQzDq2vEFqoAWYcChijQvg3Ae-3h3F-oFYo8Wh-lcrNZMxta8Ts7AYrdb7cvE2DAO8Oxl0yWJj7vTBJ1YAlO9Kwlba0EydgGY_Xyrl__amALw8p9hSqdVCrJBjYYza8oq_m6B9P1Q3AuVOSdj15yjURa5Hv_ipM9k76Fi0OobHbzfglXCNmw_qDHGhx7aiud9ZPAM-_9xgiWFuIvorltsFDznSimU3va7qorms4AMJ20moG2nmG6ov79cN5Lebj-vupWkUbZ87nd28jOSAJCtDvR2GN0mwYVdrP5jfaIHDpgOKsNTcvigq_srDUyjU-X79LDPtNKUqAwCV3fS2hiwrwlc"
 #define PS256_TOKEN_INVALID_SIGNATURE "eyJhbGciOiJQUzI1NiIsImtpZCI6IjEifQ.VGhlIHRydWUgc2lnbiBvZiBpbnRlbGxpZ2VuY2UgaXMgbm90IGtub3dsZWRnZSBidXQgaW1hZ2luYXRpb24u.t2G6YMKJVZe0U1_ZM7efsGWhSAGia5JN-K4lAk3IX7NsMSrWHwZufBXMYZW6S7t_N8xkWEuAgHOY1etwxXuUdhw8uotA-E66M-fErP8MH-N5yUR2G60g3DkcVD-GwbBCsA-Jzum_psaXMA08-3zBjrvGbldqyM51rcdt2qSDxjZ7yxRVhbFbKD0qPOUH49WZx6Mld9oMMSUoIarJitY9LwIC0cR2lXULIh5E-xia42TsNIw9F7VwPXGdHc7_VBqT7R4soxQjWDmfk5QXSMDw2WTIfEXdI3VJiUQ5qnIAe5WWW-wPsK8ughxHLabKXEQ4j7op8EvhZziLOgntGmqQzDq2vEFqoAWYcChijQvg3Ae-3h3F-oFYo8Wh-lcrNZMxta8Ts7AYrdb7cvE2DAO8Oxl0yWJj7vTBJ1YAlO9Kwlba0EydgGY_Xyrl__amALw8p9hSqdVCrJBjYYza8oq_m6B9P1Q3AuVOSdj15yjURa5Hv_ipM9k76Fi0OobHbzfglXCNmw_qDHGhx7aiud9ZPAM-_9xgiWFuIvorltsFDznSimU3va7qorms4AMJ20moG2nmG6ov79cN5Lebj-vupWkUbZ87nd28jOSAJCtDvR2GN0mwYVdrP5jfaIHDpgOKsNTcvigq_srDUyjU-X79LDPtNKUqAwCV3fS2hiwrwlc"
 #define PS256_TOKEN_INVALID_DOTS "eyJhbGciOiJQUzI1NiIsImtpZCI6IjEifQVGhlIHRydWUgc2lnbiBvZiBpbnRlbGxpZ2VuY2UgaXMgbm90IGtub3dsZWRnZSBidXQgaW1hZ2luYXRpb24u.t2G7YMKJVZe0U1_ZM7efsGWhSAGia5JN-K4lAk3IX7NsMSrWHwZufBXMYZW6S7t_N8xkWEuAgHOY1etwxXuUdhw8uotA-E66M-fErP8MH-N5yUR2G60g3DkcVD-GwbBCsA-Jzum_psaXMA08-3zBjrvGbldqyM51rcdt2qSDxjZ7yxRVhbFbKD0qPOUH49WZx6Mld9oMMSUoIarJitY9LwIC0cR2lXULIh5E-xia42TsNIw9F7VwPXGdHc7_VBqT7R4soxQjWDmfk5QXSMDw2WTIfEXdI3VJiUQ5qnIAe5WWW-wPsK8ughxHLabKXEQ4j7op8EvhZziLOgntGmqQzDq2vEFqoAWYcChijQvg3Ae-3h3F-oFYo8Wh-lcrNZMxta8Ts7AYrdb7cvE2DAO8Oxl0yWJj7vTBJ1YAlO9Kwlba0EydgGY_Xyrl__amALw8p9hSqdVCrJBjYYza8oq_m6B9P1Q3AuVOSdj15yjURa5Hv_ipM9k76Fi0OobHbzfglXCNmw_qDHGhx7aiud9ZPAM-_9xgiWFuIvorltsFDznSimU3va7qorms4AMJ20moG2nmG6ov79cN5Lebj-vupWkUbZ87nd28jOSAJCtDvR2GN0mwYVdrP5jfaIHDpgOKsNTcvigq_srDUyjU-X79LDPtNKUqAwCV3fS2hiwrwlc"
+#define PS256_TOKEN_EMPTY_SIGNATURE "eyJhbGciOiJQUzI1NiIsImtpZCI6IjEifQ.VGhlIHRydWUgc2lnbiBvZiBpbnRlbGxpZ2VuY2UgaXMgbm90IGtub3dsZWRnZSBidXQgaW1hZ2luYXRpb24u."
 
 const char jwk_pubkey_rsa_str[] = "{\"kty\":\"RSA\",\"n\":\"ALrIdhuABv82Y7K1-LJCXRy1LVdmK9IAHwmmlI-HnOrFeEsSwuCeblUgEpqz_mj7lLtZN0Gnlz-7U0hOpGCeOYXRMn8184YismuCS5PYe0"
                                   "Jfot0kMumF2IOBV94AGBSeWQcK8J-Ed3X-rkR9vovv8gXhKyRDQH4mon_cPwtdCi2PScnRlkvlOjYkib9m0QQqpvjmcd02s8BYtakRVRva2mQT_dCvRYvM4Tb5yvvRM7Iz3"
@@ -267,6 +268,15 @@ START_TEST(test_rhonabwy_verify_token_invalid)
   r_jws_free(jws);
   r_jwk_free(jwk_pubkey);
   
+  ck_assert_int_eq(r_jws_init(&jws), RHN_OK);
+  ck_assert_int_eq(r_jwk_init(&jwk_pubkey), RHN_OK);
+  ck_assert_int_eq(r_jws_parse(jws, PS256_TOKEN_EMPTY_SIGNATURE, 0), RHN_ERROR_PARAM);
+  ck_assert_int_eq(R_JWA_ALG_PS256, r_jws_get_alg(jws));
+  ck_assert_int_eq(r_jwk_import_from_json_str(jwk_pubkey, jwk_pubkey_rsa_no_alg_str), RHN_OK);
+  ck_assert_int_eq(r_jws_verify_signature(jws, jwk_pubkey, 0), RHN_ERROR_INVALID);
+  r_jws_free(jws);
+  r_jwk_free(jwk_pubkey);
+  
   ck_assert_int_eq(r_jws_init(&jws), RHN_OK);
   ck_assert_int_eq(r_jwk_init(&jwk_pubkey), RHN_OK);
   ck_assert_int_eq(r_jws_parse(jws, PS256_TOKEN, 0), RHN_OK);
